# Qualifaction Test

### Please select one answer for each of the following questions

### When you finish the questionnaire, please click "Submit" at the bottom

1. Marital Status

Widowed
Married
Separated
Divorced
Single

2. Race

African American
Caucasian
Asian
American Indian/Alaska Native
Native Hawaiian/Pacific Islander

3. Where do you live now?

Asia
Africa
Antarctica
Australia
Europe

4. What is your native language

English
Spanish
Chinese
Hindi
Arabi

5. How many years of education have you completed?

1 to 8 years
9 to 12 years
13 to 16 years
17 to 20 years
More than 20 years

6. Are you over 18-years-old?

Yes
No

7. Any other comments?